Revert "RESTCONF notification fixes"

This reverts commit 05c2c76eec9bbe553c3b4eeb9dcbb2175a25e3c2.

Change-Id: Ia92aa928ac9b6672cb229795ed4ea47f51bbafc2
diff --git a/protocols/restconf/client/api/src/main/java/org/onosproject/protocol/restconf/RestConfSBController.java b/protocols/restconf/client/api/src/main/java/org/onosproject/protocol/restconf/RestConfSBController.java
index 4cf9fe0..772aaea 100644
--- a/protocols/restconf/client/api/src/main/java/org/onosproject/protocol/restconf/RestConfSBController.java
+++ b/protocols/restconf/client/api/src/main/java/org/onosproject/protocol/restconf/RestConfSBController.java
@@ -31,48 +31,29 @@
      * callBackListener upon receiving notifications to notify the requester
      * about notifications.
      *
-     * @param device           device to make the request to
-     * @param request          url of the request
-     * @param mediaType        format to retrieve the content in
+     *
+     * @param device device to make the request to
+     * @param request url of the request
+     * @param mediaType format to retrieve the content in
      * @param callBackListener method to call when notifications arrives
      */
     void enableNotifications(DeviceId device, String request, String mediaType,
-                             RestconfNotificationEventListener callBackListener);
-
-    //TODO: To be removed once the caller to this API is updated.
-    @Deprecated void enableNotifications(DeviceId device, String request, String mediaType,
-                             RestConfNotificationEventListener callBackListener);
+                          RestConfNotificationEventListener callBackListener);
 
     /**
-     * Registers a listener for notification events that occur to restconf
+     * Register a listener for notification events that occur to restconf
      * devices.
      *
-     * @param deviceId identifier of the device to which the listener is attached
+     * @param deviceId the deviceId
      * @param listener the listener to notify
      */
     void addNotificationListener(DeviceId deviceId,
-                                 RestconfNotificationEventListener listener);
+                                 RestConfNotificationEventListener listener);
 
     /**
-     * Unregisters the listener for the device.
+     * Unregister the listener for the device.
      *
-     * @param deviceId identifier of the device for which the listener
-     *                 is to be removed
-     * @param listener listener to be removed
+     * @param deviceId the deviceId
      */
-    void removeNotificationListener(DeviceId deviceId,
-                                    RestconfNotificationEventListener listener);
-
-    //TODO: temporarily keep this API for backward compatibility.
-    @Deprecated void removeNotificationListener(DeviceId deviceId);
-
-    /**
-     * Returns true if a listener has been installed to listen to RESTCONF
-     * notifications sent from a particular device.
-     *
-     * @param deviceId identifier of the device from which the notifications
-     *                 are generated
-     * @return true if listener is installed; false otherwise
-     */
-    boolean isNotificationEnabled(DeviceId deviceId);
+    void removeNotificationListener(DeviceId deviceId);
 }
diff --git a/protocols/restconf/client/api/src/main/java/org/onosproject/protocol/restconf/RestconfNotificationEventListener.java b/protocols/restconf/client/api/src/main/java/org/onosproject/protocol/restconf/RestconfNotificationEventListener.java
deleted file mode 100644
index 230724b..0000000
--- a/protocols/restconf/client/api/src/main/java/org/onosproject/protocol/restconf/RestconfNotificationEventListener.java
+++ /dev/null
@@ -1,32 +0,0 @@
-/*
- * Copyright 2016-present Open Networking Laboratory
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- *
- *     http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
-package org.onosproject.protocol.restconf;
-
-import org.onosproject.net.DeviceId;
-
-/**
- * Notifies providers about incoming RESTCONF notification events.
- */
-public interface RestconfNotificationEventListener<T> {
-
-    /**
-     * Handles the notification event.
-     *
-     * @param deviceId restconf device identifier
-     * @param event    event payload
-     */
-    void handleNotificationEvent(DeviceId deviceId, T event);
-}
diff --git a/protocols/restconf/client/api/src/main/java/org/onosproject/protocol/restconf/RestConfNotificationEventListener.java b/protocols/restconf/client/api/src/main/java/org/onosproject/protocol/restconf/RestConfNotificationEventListener.java
index 31b3298..7866587 100644
--- a/protocols/restconf/client/api/src/main/java/org/onosproject/protocol/restconf/RestConfNotificationEventListener.java
+++ b/protocols/restconf/client/api/src/main/java/org/onosproject/protocol/restconf/RestConfNotificationEventListener.java
@@ -25,8 +25,8 @@
     /**
      * Handles the notification event.
      *
      * @param deviceId restconf device identifier
      * @param event    event payload
      */
-    void handleNotificationEvent(DeviceId deviceId, T event);
+    void handleNotificationEvent(DeviceId deviceId, T eventJsonString);
 }
@@ -25,8 +25,8 @@
      * Handles the notification event.
      *
-     * @param deviceId restconf device identifier
-     * @param event    event payload
+     * @param deviceId        restconf device identifier
+     * @param eventJsonString the json string representation of the event
      */